@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-auth
 version: 1.4.12
-id: yesod-auth-1.4.12-ee3d41f28307a05c0f72f6763eadee03
-key: yesod_3eSDIaHak3TFsktL8dQ8nb
+id: yesod-auth-1.4.12-bd2dbd422b8b288b6daf1ac8f5cb89f3
+key: yesod_4yiAqaS3YWP7Fdn0pILrAk
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -23,10 +23,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.12
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.12
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-auth-1.4.12
-hs-libraries: HSyesod-auth-1.4.12-3eSDIaHak3TFsktL8dQ8nb
+hs-libraries: HSyesod-auth-1.4.12-4yiAqaS3YWP7Fdn0pILrAk
 depends:
     aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
-    authenticate-1.3.3-a8c6eafded1415556529a09f6f8cf0a0
+    authenticate-1.3.3-53ea91e5c026eab440060c4bf4b2b35c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
@@ -36,24 +36,24 @@ depends:
     blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
-    conduit-extra-1.1.10.1-e4383b2e14cc80179dd5007ca51887df
+    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
+    conduit-extra-1.1.11-b294a7608a3a066998e74974ec65ff9b
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     email-validate-2.2.0-894e6c8f7fbbeb1604af196a15c5e993
     file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
-    http-client-0.4.27-6347f4775f754bcb55a202aff6332b65
-    http-conduit-2.1.8-7af4c72b658e9ba872144aa8bca2c27b
+    http-client-0.4.27-649349307b7fbc2da7ba4e3fdfb27d3d
+    http-conduit-2.1.8-76c320bb56047f4b6951f7d6a8e71998
     http-types-0.9-d392878af9c5e1b1993961dc71a9e177
     lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
     mime-mail-0.4.11-159ba13f631e4ac9bb3254d1bcac4f3d
     network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
     nonce-1.0.2-ba2a4fc59a4ebf1fc9363b2dcb9c988b
-    persistent-2.2.4-72be3212e3a1e06e6072e64a9625ec8e
-    persistent-template-2.1.5-8c3ce51da960caf9734845ba2763f466
+    persistent-2.2.4-a4a8972281cfa07170d8ccc96de1b890
+    persistent-template-2.1.5-71ed59f649efc8950ec7176c4454a44d
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
-    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
+    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     shakespeare-2.0.7-299569683f963ce6b42dbe4d7cdb1dae
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
@@ -62,9 +62,9 @@ depends:
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
-    yesod-core-1.4.19-25fb856b7d20f03518ef74f7c04b9148
-    yesod-form-1.4.6-1f5bbab0daee91a31c9792276fdb63be
-    yesod-persistent-1.4.0.3-94cd901c0d8cf92080c629833de6573c
+    yesod-core-1.4.19-824bf74cd5ec378da568ce71e584e959
+    yesod-form-1.4.6-cc7fd5c2de84bb46c0f6247cd76452a8
+    yesod-persistent-1.4.0.3-cff443ae4acaed8c9376536a5719bdb9
 haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
 haddock-html: /usr/share/doc/haskell-yesod-auth/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
